
/////////////////////////////////////////////////////////////////////////
// G4Tutorial:
//
// PhysicsEMElectronPenelope.hh
// 
// Assembling electromagnetic physics processes for electrons.
// 
// The considered processes are G4MultipleScattering, G4PenelopeIonisation
// and G4PenelopeBremsstrahlung
//
/////////////////////////////////////////////////////////////////////////


#ifndef PHYSICSEMELECTRONPENELOPE_HH
#define PHYSICSEMELECTRONPENELOPE_HH

#include "G4VPhysicsConstructor.hh"
#include "globals.hh"


// G4VPhysicsConstructor is the abstract base class for physics constructors:

class PhysicsEMElectronPenelope : public G4VPhysicsConstructor {

 public: 
   PhysicsEMElectronPenelope(const G4String& name = "Electron-Penelope");
   virtual ~PhysicsEMElectronPenelope();
  
 

   // G4VPhysicsConstructor has two pure virtual methods which must be 
   // implemented by the user: ConstructParticle and ConstructProcess.
   // Since only physics processes are dealt with here, ConstructParticle
   // is irrelevant and performs no action. ConstructProcess is used to
   // instantiate all physics processes relevant for the considered particle
   // and type of interaction.
   void ConstructParticle() { };
   void ConstructProcess();
};

#endif // PHYSICSEMELECTRONPENELOPE_HH








